This part of the project documentation focuses on
an **information-oriented** approach. Use it as a
reference for the technical implementation of the
Theta Data Python API.


> Finding a concept confusing? Let us know!

::: thetadata.client
::: thetadata.enums
::: thetadata.exceptions
